@@ -94,7 +94,8 @@ class YouTube(VideoExtractor):
         f1 = match1(js, r'\.set\(\w+\.sp,encodeURIComponent\(([$\w]+)') or \
             match1(js, r'\.set\(\w+\.sp,\(0,window\.encodeURIComponent\)\(([$\w]+)') or \
             match1(js, r'\.set\(\w+\.sp,([$\w]+)\(\w+\.s\)\)') or \
-            match1(js, r'"signature",([$\w]+)\(\w+\.\w+\)')
+            match1(js, r'"signature",([$\w]+)\(\w+\.\w+\)') or \
+            match1(js, r'=([$\w]+)\(decodeURIComponent\(')
         f1def = match1(js, r'function %s(\(\w+\)\{[^\{]+\})' % re.escape(f1)) or \
                 match1(js, r'\W%s=function(\(\w+\)\{[^\{]+\})' % re.escape(f1))
         f1def = re.sub(r'([$\w]+\.)([$\w]+\(\w+,\d+\))', r'\2', f1def)
@@ -222,7 +223,7 @@ class YouTube(VideoExtractor):
                 except:
                     if 'url_encoded_fmt_stream_map' not in video_info:
                         stream_list = json.loads(video_info['player_response'][0])['streamingData']['formats']
-                    else: 
+                    else:
                         stream_list = video_info['url_encoded_fmt_stream_map'][0].split(',')
                     if re.search('([^"]*/base\.js)"', video_page):
                         self.html5player = 'https://www.youtube.com' + re.search('([^"]*/base\.js)"', video_page).group(1)
@@ -451,6 +452,8 @@ class YouTube(VideoExtractor):
                                for afmt in video_info['adaptive_fmts'][0].split(',')]
                 else:
                     streams = json.loads(video_info['player_response'][0])['streamingData']['adaptiveFormats']
+                    # streams without contentLength got broken urls, just remove them (#2767)
+                    streams = [stream for stream in streams if 'contentLength' in stream]
                     for stream in streams:
                         stream['itag'] = str(stream['itag'])
                         if 'qualityLabel' in stream:
